Description Usage Arguments Details Value
Solve for each value of x that gives Coppock curve value y.
1 | coppock_curve_solve_each(x, n1 = 14L, n2 = 11L, n3 = 10L, y = 0)
|
x |
A vector |
n1 |
Rate of change period #1 |
n2 |
Rate of change period #2 |
n3 |
Weighted moving average period |
y |
Coppock curve value |
The calculation of the Coppock curve is such that changing one value of
x would affect the Coppock curve at other points. Therefore, the
solution for each x is independent and is found by holding constant
all other values of x.
A vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.